/* libfir/src/libfir++/100_Filter.cc
 * 
 *  Copyright: ©2014, Laurence Withers.
 *  Author: Laurence Withers <l@lwithers.me.uk>
 *  License: GPLv3
 */



Filter::Filter(int ncoeff, const double* coeff, Symmetry symm)
{
    fi_ = fir_filter_new(ncoeff, coeff, static_cast<enum fir_symmetry>(symm));
}



Filter::Filter(const Filter& other)
{
    fi_ = fir_filter_clone(other.fi_);
}



Filter::Filter(const std::vector<double>& coeff, Symmetry symm)
{
    int ncoeff = coeff.size();
    double* cc = static_cast<double*>(alloca(ncoeff * sizeof(double)));

    for(int i = 0; i < ncoeff; ++i) cc[i] = coeff[i];
    fi_ = fir_filter_new(ncoeff, cc, static_cast<enum fir_symmetry>(symm));
}



Filter::Filter(struct fir_filter_t* fi)
{
    fi_ = fi;
}



Filter::~Filter()
{
    fir_filter_free(fi_);
}



double
Filter::f(double x)
{
    return fir_filter(fi_, x);
}



Symmetry
Filter::symmetry() const
{
    return static_cast<Symmetry>(fir_filter_get_symmetry(fi_));
}



int
Filter::ncoeff() const
{
    return fir_filter_get_ncoeff(fi_);
}



double
Filter::coeff(int idx) const
{
    return fir_filter_get_coeff(fi_, idx);
}



std::complex<double>
Filter::response(double freq) const
{
    return std::complex<double>(fir_filter_response(fi_, freq));
}



/* options for text editors
vim: expandtab:ts=4:sw=4
*/
