/* libfir/src/libfir++/200_CommonFilters.h
 * 
 *  Copyright: ©2014, Laurence Withers.
 *  Author: Laurence Withers <l@lwithers.me.uk>
 *  License: GPLv3
 */



/*! \defgroup libfirpp_common Common filter types

\ingroup libfirpp

*/
/*!@{*/



/*! \brief Brickwall low-pass linear phase: sinc filter.

\param npoints Number of points required (≥1).
\param corner Corner frequency as fraction of sample rate.
\param gain Gain of filter.
\returns Newly-allocated %FIR filter.

Builds a truncated-sinc filter which has a low-pass, brickwall effect (cutoff
at \a corner, which is a fraction of sampling rate, i.e. 0 &lt; \a corner &lt;
0.5).

The number of points \a npoints is a trade-off between accuracy of filter (an
ideal sinc filter would have an infinite number of points) and computation time.
\a npoints may be odd or even; symmetry will be exploited in either case.

The DC gain of the filter is normalised to \a gain, which is often 1.0.

*/
Filter SincLowpass(int npoints, double corner, double gain);



Filter BlackmanLowpass(int npoints, double corner, double gain);

Filter LanczosLowpass(int npoints, double corner, double gain, int a);



/*!@}*/
/* options for text editors
vim: expandtab:ts=4:sw=4:syntax=cpp.doxygen
*/
